@@ -3,9 +3,9 @@ from typing import Optional
 
 from httpx import Response
 
-from tsugu_api_async import settings
-from tsugu_api_async._network import Api
-from tsugu_api_async._typing import (
+from tsugu_api_core import settings
+from tsugu_api_core._network import Api
+from tsugu_api_core._typing import (
     _QueryResponse,
     _SubmitResponse
 )
@@ -16,6 +16,7 @@ async def station_submit_room_number(
     platform: str,
     user_id: str,
     user_name: str,
+    avatar_url: Optional[str] = None,
     bandori_station_token: Optional[str] = None
 ) -> _SubmitResponse:
     '''提交车牌号
@@ -26,32 +27,33 @@ async def station_submit_room_number(
         platform (str): 平台
         user_id (str): 用户 ID
         user_name (str): 用户名
+        avatar_url (Optional[str]): 用户头像 URL
         bandori_station_token (Optional[str]): Bandori 车站令牌，不填则使用 Tsugu 后端配置
 
     返回:
         _SubmitResponse: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.userdata_backend_url + '/station/submitRoomNumber'
-    
     # 构建数据
     data = {
         'number': number,
         'rawMessage': raw_message,
         'platform': platform,
-        'user_id': user_id,
+        'userId': user_id,
         'userName': user_name,
         'time': int(time())
     }
+    if avatar_url:
+        data['avatarUrl'] = avatar_url
     if bandori_station_token:
         data['bandoriStationToken'] = bandori_station_token
     
     # 发送请求
     resonse = await Api(
-        url,
+        settings.userdata_backend_url,
+        '/station/submitRoomNumber',
         proxy=settings.userdata_backend_proxy
-    ).post(data)
+    ).apost(data)
     if isinstance(resonse, Response): return resonse.json()
     return await resonse.json()
 
@@ -62,13 +64,11 @@ async def station_query_all_room() -> _QueryResponse:
         _QueryResponse: 响应信息
     '''
     
-    # 构建 URL
-    url = settings.userdata_backend_url + '/station/queryAllRoom'
-    
     # 发送请求
     response = await Api(
-        url,
+        settings.userdata_backend_url,
+        '/station/queryAllRoom',
         proxy=settings.userdata_backend_proxy
-    ).get()
+    ).aget()
     if isinstance(response, Response): return response.json()
     return await response.json()
